# eric7.WebBrowser.OpenSearch

Package implementing the opensearch search engine interfaces.

### Packages

DefaultSearchEngines | Package conatining the default search engine definitions.

### Modules

OpenSearchDialog | Module implementing a dialog for the configuration of search engines.
OpenSearchEditDialog | Module implementing a dialog to edit the data of a search engine.
OpenSearchEngine | Module implementing the open search engine.
OpenSearchEngineAction | Module implementing a QAction subclass for open search.
OpenSearchEngineModel | Module implementing a model for search engines.
OpenSearchManager | Module implementing a manager for open search engines.
OpenSearchReader | Module implementing a reader for open search engine descriptions.
OpenSearchWriter | Module implementing a writer for open search engine descriptions.